/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.ImageDiffer;

import java.awt.Point;
import java.awt.image.BufferedImage;

public class ComparisonResult
{
    private boolean equalsImages;
    private BufferedImage diffImage;
    private Point rectangleMin;
    private Point rectangleMax;
    private int areaWidth;
    private int areaHeight;
    private int totalPixels;
    private int differentPixels;
    private int smallDifferences;
    private int equalPixels;
    private String testName;

    public ComparisonResult(String testName, boolean equalsImages, BufferedImage diffImage, Point rectangleMin, Point rectangleMax,
            int areaWidth, int areaHeight, int totalPixels, int differentPixels, int smallDifferences, int equalPixels)
    {
        super();
        this.testName = testName;
        this.equalsImages = equalsImages;
        this.diffImage = diffImage;
        this.rectangleMin = rectangleMin;
        this.rectangleMax = rectangleMax;
        this.areaWidth = areaWidth;
        this.areaHeight = areaHeight;
        this.totalPixels = totalPixels;
        this.differentPixels = differentPixels;
        this.smallDifferences = smallDifferences;
        this.equalPixels = equalPixels;
    }

    public boolean isEqualsImages()
    {
        return this.equalsImages;
    }

    public BufferedImage getDiffImage()
    {
        return this.diffImage;
    }

    public Point getRectangleMin()
    {
        return this.rectangleMin;
    }

    public Point getRectangleMax()
    {
        return this.rectangleMax;
    }

    public int getAreaWidth()
    {
        return this.areaWidth;
    }

    public int getAreaHeight()
    {
        return this.areaHeight;
    }

    public int getTotalPixels()
    {
        return this.totalPixels;
    }

    public int getDifferentPixels()
    {
        return this.differentPixels;
    }

    public int getSmallDifferences()
    {
        return this.smallDifferences;
    }

    public int getEqualPixels()
    {
        return this.equalPixels;
    }

    public String getTestName()
    {
        return this.testName;
    }
    
    public String getComparisonStatus()
    {
        return this.isEqualsImages() ? "same" : "different";
    }

    public String getAreaAsString()
    {
        return String.format("%d&times;%d", Integer.valueOf(this.getAreaWidth()), Integer.valueOf(this.getAreaHeight()));
    }

    public String getRectangleAsString()
    {
        return String.format("[%d, %d] - [%d, %d]", Integer.valueOf(this.getRectangleMin().x),
                Integer.valueOf(this.getRectangleMin().y), Integer.valueOf(this.getRectangleMax().x),
                Integer.valueOf(this.getRectangleMax().y));
    }
}
